@@ -730,6 +730,10 @@ Want to download more cities?</source>
         <source>Scale of interface</source>
         <translation>Масштаб интерфейса</translation>
     </message>
+    <message>
+        <source>Scale of buttons</source>
+        <translation>Масштаб кнопок</translation>
+    </message>
     <message>
         <source>Caching graphics</source>
         <translation>Кешировать графику</translation>
