@@ -1,17 +1,32 @@
 #ifndef ABOUT_H
 #define ABOUT_H
 
+#include <qglobal.h>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
+
 #include <QDialog>
 
 #include "mainwindow.h"
+#include "mapview/maplayer.h"
 #include "flickcharm.h"
 
+#ifdef QMETRO_HAVE_ALARM
+#include "alarm/audiooutput.h"
+#endif
+
+#ifdef QMETRO_HAVE_VIBRO
+//#include "alarm/vibro.h"
+#endif
+
 #ifdef Q_OS_SYMBIAN
 extern QString VERSION;
 #endif
 extern MainWindow *mainWnd;
-extern QString URL_MAPS;
+extern QString appPath,URL_MAPS,SKIN_DEFAULT;
 
 class About : public QDialog
 {
@@ -20,6 +35,9 @@ class About : public QDialog
 public:
     explicit About(QWidget *parent): QDialog(parent)
     {
+#ifdef QMETRO_HAVE_ALARM
+     Player=NULL;
+#endif
      //Logo= new QLabel();
      OK=NULL;
      Info= new QTextBrowser();
@@ -44,6 +62,20 @@ public:
      //Logo->setContentsMargins(0,5,0,0);
      //Logo->setPixmap(QPixmap(":/qmetro.png"));
 
+     QString AuthorOfSkin;
+     if(mainWnd->Config.appSkinName!=SKIN_DEFAULT)
+     {
+      QSettings ini(appPath+"skin/"+mainWnd->Config.appSkinName+"/main.ini",QSettings::IniFormat);
+      AuthorOfSkin=ini.value("Main/Author").toString();
+      if(!AuthorOfSkin.isEmpty()) AuthorOfSkin="<br><br>"+tr("Author of skin")+":<br>"+AuthorOfSkin.remove(QRegExp("<[^>]*>"));
+     }
+
+     QString LIBS,MODULES=" (Core,Gui";
+#ifdef QMETRO_HAVE_ALARM
+     MODULES+=",Multimedia";
+     LIBS+="<li>&nbsp;libmodplug";
+#endif
+     MODULES+=")";
      QString hr=QString("<p><table height=\"2\" width=\"100%\" bgcolor=\"%1\"><tr><td></table></p>")
                 .arg(palette().color(QPalette::Mid).name());
      QString text=
@@ -51,25 +83,31 @@ public:
              "<img "+(0 ? QString("width=\"%1\" height=\"%1\"").arg(mainWnd->Config.appIconSize):"")+" align=\"left\" src=\":/qmetro.png\">"
              "<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=9EZQ47YPVAF36\">"
              "<img "+(0 ? QString("width=\"%1\" height=\"%2\"").arg(mainWnd->Config.appIconSize).arg(mainWnd->Config.appIconSize/1.6):"")+" src=\":/img/donate.png\"></a>"
-             "<td><p><font size=6><b>qMetro</b></font><br>"
-             "%4<br><br>"
-             "%5 %1<br>"
-             "&copy; 2011-2012<br><a href=\"mailto:guuleon@gmail.com\">Gusak Leonid</a><br>"
+             "<td><p><font size=6><b>qMetro</b></font>"
+//          +"<br><sup><font size=5 color=\"#a90105\">"+tr("Happy New Year!")+"</font></sup>"+
+             "<br>%4"
+             "<br><br>%5 %1<br>"
+             "&copy; 2011-2013<br><a href=\"mailto:guuleon@gmail.com\">Gusak Leonid</a><br>"
              "<a href=\"http://qmetro.sf.net\">qmetro.sf.net</a></table></p>"
+            +(mainWnd->Config.locale!="ru" ? "":"<br><center><table border=1><tr><td><small>WMR133269969667<small></table></center>")+
+
              "<hr><br>%6:<br><a href=\"mailto:Boris@pMetro.su\">Muradov Boris</a>"
              " (<a href=\"%10\">pMetro</a>)"
              "<br><br>%11"
-             "<hr><b>%7:</b>"
+            + AuthorOfSkin +
+             "<hr><b>%7 ("+QString("%1/%2").arg( mainWnd->map->nodeByID.count() ).arg( ((TMapLayer*)mainWnd->map->layer.at(0))->route.count() ) +"):</b>"
              "<p>%3</p>"
-             "<hr><b>%8:</b><ul type=\"circle\"><li>&nbsp;Qt %2<li>&nbsp;zlib + OSDaB</ul>"
+             "<hr><b>%8:</b><ul type=\"circle\"><li>&nbsp;Qt %2 %12</ul>"
              "<hr>%9")
-     .arg(VERSION).arg(QT_VERSION_STR).arg((mainWnd->map->params.mapAuthors.isEmpty() ? tr("Unknown author"):mainWnd->map->params.mapAuthors)) // 1
+     .arg(VERSION).arg(QT_VERSION_STR+MODULES).arg((mainWnd->map->params.mapAuthors.isEmpty() ? tr("Unknown author"):mainWnd->map->params.mapAuthors)) // 1
      .arg(tr("transit system map")).arg(tr("Version")).arg(tr("Author of map file format")) // 3
      .arg(tr("About current map file")).arg(tr("This program uses")) // 6
      .arg(tr("This program is distributed in the hope that it will be useful, "
              "but WITHOUT ANY WARRANTY; without even the implied warranty of "
              "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-             "GNU General Public License for more details.")).arg(URL_MAPS).arg(tr("Author of translation: Gusak Leonid").replace(": ",":<br>"));
+             "GNU General Public License for more details.")).arg(URL_MAPS) // 9 10
+     .arg(tr("Author of translation: Gusak Leonid").replace(": ",":<br>")) // 11
+     .arg("<li>&nbsp;zlib + OSDaB"+LIBS); // 12
 
      text.replace("<hr>",hr);
 
@@ -94,7 +132,6 @@ public:
 //#ifndef Q_WS_MAEMO_5
      if(mainWnd->MobileVersion)
      {
-      //OK= new QDialogButtonBox(QDialogButtonBox::Ok);
       OK = new QPushButton(tr("OK"));
       //connect(OK,SIGNAL(clicked()),mainWnd,SLOT(toFullScreen()));
       connect(OK,SIGNAL(clicked()),this,SLOT(close()));
@@ -103,13 +140,35 @@ public:
      }
 //#endif
      setLayout(VLayout);
-     //connect(this,SIGNAL())
      if(OK) OK->setFocus();
+
+#ifdef QMETRO_HAVE_VIBRO
+// VibroFeedback vibro;
+// vibro.start();
+#endif
+
+#ifdef QMETRO_HAVE_ALARM
+     playerCreate();
+   //Player->loadAudioFile(":/test.xmz");
+
+ #ifdef Q_OS_SYMBIAN
+//        qDebug() << "ATTENTION: Stupid rule of Nokia QA!";
+        connect(qApp,SIGNAL(appFocusGained()),this,SLOT(playerCreate()));
+        connect(qApp,SIGNAL(appFocusLost()),this,SLOT(playerDelete()));        
+ #endif
+#endif
+
     }
     ~About()
     {
      if(OK) delete OK;
      delete Info;
+#ifdef QMETRO_HAVE_ALARM
+     hide(); // alarm creating 1-2 sec  and can be deleting after
+     QApplication::processEvents();
+     delete Player;
+#endif
+
     }
 
 private:
@@ -125,6 +184,23 @@ private:
     //QLabel *Logo;
     QTextBrowser *Info;
 
+#ifdef QMETRO_HAVE_ALARM
+ AudioPlay *Player;
+
+public slots:
+
+ void playerDelete() { delete Player; Player=0; }
+ void playerCreate()
+ {
+  if(!Player)
+  {
+   Player = new AudioPlay(this,":/audio/about.xm");
+   Player->start();
+  }
+ }
+
+#endif
+
 protected:
     void keyPressEvent(QKeyEvent *e)
     {
