@@ -17,7 +17,7 @@ class TCompleter : public QObject
     Q_OBJECT
 
 public:
-    TCompleter(TMapView *map,QLineEdit *parent = 0);
+    TCompleter(TMapView *mapView,QLineEdit *parent = 0);
     ~TCompleter();
     bool eventFilter(QObject *obj, QEvent *ev);
     void showCompletion(QList< QPair<QString,QColor> > list);
@@ -42,6 +42,10 @@ private:
     QList< QPair<QString,QColor> > list;
     QList<int> idFiltred;
 
+    bool MobileVersion;
+    TMapView *map;
+
+    char indName,indColor;
 };
 
 #endif
