@@ -35,26 +35,27 @@
 
 
 #ifdef Q_OS_SYMBIAN
-QString VERSION="0.6.7";
+QString VERSION="0.6.8";
 #endif
 
 QString URL_MAPS="http://pmetro.su/Maps.html";
 QString URL_TRANSLATE="http://translate.google.com/translate?sl=ru&tl=%1&u=%2";
 
 bool LITE=0;
-int ICONSIZE=24; // begin size 100% scale
+int ICONSIZE_DEFAULT=24,ICONSIZE=ICONSIZE_DEFAULT; // begin size 100% scale
 QString STYLE_MAP_DEFAULT=
-  "QLabel,QLineEdit{color:black;font:bold;max-height:1.6em;border:0.05em solid grey;border-radius:0.3em;background:qlineargradient(x1:0,y1:0,x2:0,y2:1,stop:0 #dadbde,stop:1 rgba(255,255,255,60%));} "
-  "QToolButton{border-image:url(:/img/button_inactive.png);height:%1px;width:%1px;background:transparent;padding:0.2em;margin-top:%6px;margin-left:%6px;} "
-  "QToolButton:pressed{border-image:url(:/img/button_active.png);margin-top:%5px;margin-left:%5px;} "
-//  "QLabel{padding-left:%7px;padding-right:%7px;margin-left:%5px;} "
+  "QLabel,QLineEdit{color:black;font:bold;max-height:1.6em;border:0.1em solid rgba(128,128,128,50%);border-radius:0.5em;background:qlineargradient(x1:0,y1:0,x2:0,y2:1,stop:0 rgba(245,245,245,90%),stop:1 rgba(255,255,255,80%));}"
+  "QToolButton{border-image:url(:/img/button_inactive.png);height:%1px;width:%1px;background:transparent;padding:0.2em;margin-top:%7px;margin-left:%7px;} "
+  "QToolButton:pressed{border-image:url(:/img/button_active.png);margin-top:%6px;margin-left:%6px;} "
+  "QLabel{margin-left:%7px;} "
   "QLineEdit{padding-left:%6px;}/*%1%2%3%4%5%6%7*/",
   STYLE_MAP=STYLE_MAP_DEFAULT;
 
 QString STYLE_MAIN_DEFAULT=
   "QToolBox::tab{padding-left:1em;text-transform:uppercase;background:palette(button);border-bottom:0.2em solid palette(highlight);border-bottom-left-radius:0.5em;border-bottom-right-radius:0.5em;}"
   "QToolBox::tab:selected{font:bold;border-bottom:0.3em solid palette(highlight);}/*%1%2%3%4%5%6%7*/",
-STYLE_MAIN=STYLE_MAIN_DEFAULT, SKIN_DEFAULT, STYLE_FONT_DEFAULT;
+        STYLE_MAIN=STYLE_MAIN_DEFAULT,
+        SKIN_DEFAULT, STYLE_FONT_DEFAULT;
 
 MainWindow *mainWnd;
 
@@ -93,10 +94,9 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  IniKeyStr << "Skin"<<"StationCustomFont"<<"StationFont"<<"StationBack"<<"StationShadow"<<"StationBackColor"<<"StationShadowColor"<<
               "StationUpperCase"<<"StationWordWrap"<<"StationTransparency"<<
               "MapShowScrollbar"<<"WindowFullScreen"<<"MapShowTime"<<"MapShowBackground"<<"MapAntialiasing"<<"MapFastScrolling"<<
-              "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"MapCaching"<<"UiScale"<<"SwipeRoutes";
+              "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"MapCaching"<<"UiScale"<<"UiButtonScale"<<"SwipeRoutes";
 
 
- Config.appUiScale=1;
  appPath=qApp->applicationDirPath()+"/";
  appConfigFile=cachePath="";
 
@@ -114,10 +114,10 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  setAttribute(Qt::WA_Maemo5AutoOrientation);
  setAttribute(Qt::WA_Maemo5StackedWindow);
  setAttribute(Qt::WA_Maemo5NonComposited);
- ICONSIZE=64;
+// ICONSIZE=64;
  #else
  // MOBILE NONNATIVE INTERFACE
- Config.appUiScale=2.5;
+// Config.appUiScale=2.5;
 // qApp->setStyle("cleanlooks");
  MobileVersion=2;
 
@@ -147,7 +147,7 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
 #endif
 #ifdef Q_OS_SYMBIAN
  appPath="e:/Data/qMetro/";
- ICONSIZE=56;
+// ICONSIZE=56;
 #endif
 
  if(appConfigFile.isEmpty()) appConfigFile=appPath+"config.ini";
@@ -160,15 +160,14 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  ini->beginGroup("Main");
  if(VERSION!=ini->value("Version").toString())
  {
-  ini->remove(IniKeyStr[ikWUiScale]);
-  ini->remove("Styles");
   removeDir(cachePath);
  }
 
  Config.mapKineticScrollCheck=0; // its work so bad...
  Config.locale=ini->value("Locale","").toString();
  Config.dockWidth=ini->value("DockWidth",180).toInt();
- Config.appUiScale=ini->value(IniKeyStr[ikWUiScale],Config.appUiScale).toReal();
+ Config.appUiScale=ini->value(IniKeyStr[ikWUiScale],qreal(1)).toReal();
+ Config.appUiButtonScale=ini->value(IniKeyStr[ikWUiButtonScale],qreal(1)).toReal();
 
  key="Mobile";
  if(ini->contains(key)) MobileVersion=ini->value(key).toInt();
@@ -184,17 +183,14 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
 
 
  Config.appFirstStart=!ini->contains(IniKeyStr[ikMLastFile]);
- //Config.appFont.fromString(ini->value("Font",qApp->font().toString()).toString());
+ Config.appFont.fromString(ini->value("Font",qApp->font().toString()).toString());
  if(Config.locale.isEmpty()) Config.locale=QLocale::system().name().section("_",0,0);
  if(Config.locale=="uk" || Config.locale=="be" || Config.locale=="kk" || Config.locale=="ab" || Config.locale=="ky") Config.locale="ru";
 
  toggleLang(Config.locale);
 
  ui->setupUi(this); // UI #############################
-// loadSkin(ini->value("Skin").toString());
- //ui->labelLoading->setText("<H1>"+ui->labelLoading->text()+"</H1>");
- showPageLoading();
- restoreState(QByteArray::fromHex(ini->value("WindowState").toByteArray()));
+
 
  if(MobileVersion)
  {
@@ -203,16 +199,12 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
   removeToolBar(ui->toolBar);
 
   // set UI size for device
-  Config.appIconSize=ICONSIZE=qMin(qApp->desktop()->width(),qApp->desktop()->height()) / qreal(6.5);
-#if defined(Q_WS_MAEMO_5)
-  Config.appFont.setPixelSize(ICONSIZE/qreal(2.7));
-#else
-  Config.appFont.setPixelSize(ICONSIZE/qreal(2.5));
-#endif
-  Config.appUiScale=1;
+  Config.appIconSize=ICONSIZE_DEFAULT=ICONSIZE=qMin(qApp->desktop()->width(),qApp->desktop()->height()) / qreal(6.5);
+//  Config.appUiScale=1;
  }
  else
  {
+  restoreState(QByteArray::fromHex(ini->value("WindowState").toByteArray()));
   key="WindowGeometry";
   if(ini->contains(key))
   {
@@ -226,6 +218,10 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
   }
  }
 
+ loadSkin(ini->value("Skin").toString());
+ //ui->labelLoading->setText("<H1>"+ui->labelLoading->text()+"</H1>");
+ showPageLoading();
+
 #if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
  ui->menuHelp->setIcon(QIcon());
 #endif
@@ -264,7 +260,6 @@ if(LITE)
 
  qApp->setFont(Config.appFont);
  setWindowTitle(windowTitle()+(MobileVersion ? QString(""):QString(" ")+VERSION));
-
  if(Config.appFullscreen) //AppConfig.value(igMain).value(ikWFullScreen).toInt()
       toFullScreen();
  else (MobileVersion ? showMaximized():show());
@@ -290,8 +285,6 @@ if(LITE)
  connect(map,SIGNAL(delayNames(QStringList)),this,SLOT(setDelayNames(QStringList)));
  connect(map,SIGNAL(trackNames(QStringList)),this,SLOT(setTrackNames(QStringList)));
 
- ui->toolBar->setIconSize(QSize(Config.appIconSize,Config.appIconSize));
-
  if(!MobileVersion)
  {
   QHBoxLayout *EditLayout = new QHBoxLayout;
@@ -332,7 +325,7 @@ if(LITE)
   //setCentralWidget(map);
   mUi = new TMobileUi(this,map);
  }
- setScaleForUi(Config.appUiScale);
+
 
  // apply config
  map->show();
@@ -529,8 +522,9 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
   break;
  case QEvent::Resize:
   {
-   map->selectedNodesToFront(1);
    map->mapStartDragging();
+   map->selectedNodesToFront(1);
+   //if(MobileVersion) Completer->popup->setStyleSheet(QString("max-width:%1px;").arg(width()-Config.appIconSize*2));
    //map->fitMap();
    return 1;
   }
@@ -669,11 +663,16 @@ void MainWindow::loadSkin(QString skinName)
     QFile::remove(info.absoluteFilePath());
   }
 
- if(Config.appSkinName==skinName) return;
+ if(Config.appSkinName==skinName)
+ {
+  setScaleForUi();
+  return;
+ }
 
  QString fullPath=skinPath+skinName+"/";
  QString styleSheet,value,url="url(",rc=":#(",args="/*%1%2%3%4%5%6%7*/";
 //qDebug() << 1;
+
  // load default icons
  if(actionIcons.count())
  {
@@ -684,10 +683,12 @@ void MainWindow::loadSkin(QString skinName)
 //qDebug() << 1.1;
  }
 
+ // load just style
  if(!QFile::exists(fullPath))
  {
-  STYLE_MAIN=STYLE_MAIN_DEFAULT+args;
-  STYLE_MAP=STYLE_MAP_DEFAULT+args;
+  STYLE_MAIN=STYLE_MAIN_DEFAULT;
+  STYLE_MAP=STYLE_MAP_DEFAULT;
+  ICONSIZE=ICONSIZE_DEFAULT;
   if(QStyleFactory::keys().contains(skinName,Qt::CaseInsensitive))
   {
    qApp->setStyle(skinName);
@@ -695,11 +696,13 @@ void MainWindow::loadSkin(QString skinName)
 //   qDebug() << 1.15;
   }
   Config.appFont.fromString(STYLE_FONT_DEFAULT);
-  setScaleForUi(Config.appUiScale);
+  setScaleForUi();
 // qDebug() << 1.2;
   return;
  }
-//qDebug() << 2;
+// qDebug() << 2;
+
+ // load skin
  Config.appSkinName=skinName;
  QFile fileStyle;
  styleSheet="";
@@ -726,12 +729,20 @@ void MainWindow::loadSkin(QString skinName)
  ini.beginGroup("Main");
  value=ini.value("Style").toString().trimmed();
  if(!value.isEmpty()) qApp->setStyle(value);
+// value=ini.value("MapColor").toString().trimmed();
+// if(!value.isEmpty()) map->params.mapColorBack.setNamedColor(value);
  value=ini.value("Font",STYLE_FONT_DEFAULT).toString().trimmed();
+
  Config.appFont.fromString(value);
- if(MobileVersion) Config.appFont.setPixelSize(ICONSIZE/2.6);
+
+ ICONSIZE=ini.value("IconSize").toInt();
+ if(!ICONSIZE) ICONSIZE=ICONSIZE_DEFAULT;
+
+ setScaleForUi();
+
  ini.endGroup();
 
- setScaleForUi(Config.appUiScale);
+
 
  ini.beginGroup("Icons");
 
@@ -1121,8 +1132,11 @@ void MainWindow::closeEvent(QCloseEvent * e)
  QString key;
  ini.beginGroup("Main");
  ini.setValue("Version", VERSION);
- ini.setValue("WindowState", saveState().toHex());
- if(!MobileVersion) ini.setValue("WindowGeometry", saveGeometry().toHex());
+ if(!MobileVersion)
+ {
+  ini.setValue("WindowState", saveState().toHex());
+  if(!MobileVersion) ini.setValue("WindowGeometry", saveGeometry().toHex());
+ }
  ini.setValue(IniKeyStr[ikMLastFile],map->params.mapFile);
  key="Locale";
  if(ini.contains(key))
@@ -1172,7 +1186,7 @@ void MainWindow::closeEvent(QCloseEvent * e)
 void applySettings(const IniSettingMap &settings)
 {
  TMapView *map=mainWnd->map;
- if(!settings.count()) return;
+// if(!settings.count()) return;
 
  QFont nodeFont;
  QMapIterator<IniGroup,IniKeyMap> i(settings);
@@ -1189,7 +1203,7 @@ void applySettings(const IniSettingMap &settings)
 
    switch(j.key())
    {
-   case ikSkin: mainWnd->loadSkin(value); break;
+//   case ikSkin: mainWnd->loadSkin(value); break;
    case ikStationCustomFont: map->config.enableCustomFont=value.toInt(); break;
    case ikStationFont: nodeFont.fromString(value); break;
    case ikStationBack: map->config.enableStationBackColor=value.toInt(); break;
@@ -1215,12 +1229,14 @@ void applySettings(const IniSettingMap &settings)
    case ikMLastFile: map->config.mapLastFile=value; break;
    case ikMCaching: map->config.enableCaching=value.toInt(); break;
    case ikMSwipeRoutes: map->config.enableSwipeRoutes=value.toInt(); break;
-   case ikWUiScale: mainWnd->setScaleForUi((qreal)value.toFloat()); break;
+   case ikWUiScale: mainWnd->Config.appUiScale=qreal(value.toFloat()); break; // setScaleForUi((qreal)value.toFloat()); break;
+   case ikWUiButtonScale: mainWnd->Config.appUiButtonScale=qreal(value.toFloat()); break;
    default: break;
    }
   }
  }
 
+ mainWnd->loadSkin(settings.value(igMain).value(ikSkin)); // + ikWUiScale + ikWUiButtonScale
  map->applyConfig(); // + load last map
 
  // change params
@@ -1319,16 +1335,16 @@ void loadSettings()
   AppConfig.insert(igMapView,key);
  }
 
- if(AppConfig.value(igMain).value(ikSkin).isEmpty())
- {
-  IniKeyMap key=AppConfig.value(igMain);
-  key.insert(ikSkin,mainWnd->Config.appSkinName);
-  AppConfig.erase(AppConfig.find(igMain));
-  AppConfig.insert(igMain,key);
- }
+ // if(AppConfig.value(igMain).value(ikSkin).isEmpty())
+ // {
+ //  IniKeyMap key=AppConfig.value(igMain);
+ //  key.insert(ikSkin,mainWnd->Config.appSkinName);
+ //  AppConfig.erase(AppConfig.find(igMain));
+ //  AppConfig.insert(igMain,key);
+ // }
 
  applySettings(AppConfig);
- map->applyConfig();
+// map->applyConfig();
 }
 
 bool removeDir(const QString &DirName)
@@ -1431,15 +1447,28 @@ void MainWindow::on_mFullScreen_toggled(bool checked)
 
 }
 
-void MainWindow::setScaleForUi(qreal UiScale)
+void MainWindow::setScaleForUi(qreal UiScale,qreal UiButtonScale)
 {
- if(UiScale<=qreal(0.0)) return;
+ if(UiScale<=qreal(0.0)) UiScale=Config.appUiScale;
+ if(UiButtonScale<=qreal(0.0)) UiButtonScale=Config.appUiButtonScale;
  //qDebug() << UiScale;
- QFont font=Config.appFont;
+ ICONSIZE=ICONSIZE_DEFAULT*UiButtonScale;
  Config.appIconSize=ICONSIZE*UiScale;
+
+ if(MobileVersion)
+ {
+#if defined(Q_WS_MAEMO_5)
+  Config.appFont.setPixelSize(ICONSIZE_DEFAULT/qreal(2.7));
+#else
+  Config.appFont.setPixelSize(ICONSIZE_DEFAULT/qreal(2.5));
+#endif
+ }
+
+ QFont font=Config.appFont;
  if(font.pixelSize()>0)
       font.setPixelSize(font.pixelSize()*UiScale);
  else font.setPointSizeF(font.pointSizeF()*UiScale);
+
  qApp->setFont(font);
  qApp->setStyleSheet(STYLE_MAIN.arg(Config.appIconSize)          // 1
                                      .arg(int(Config.appIconSize/2))   // 2
@@ -1453,5 +1482,5 @@ void MainWindow::setScaleForUi(qreal UiScale)
       mUi->setToolbarIconSize(Config.appIconSize);
  else ui->toolBar->setIconSize(QSize(Config.appIconSize,Config.appIconSize));
  Config.appUiScale=UiScale;
+ Config.appUiButtonScale=UiButtonScale;
 }
-
