@@ -13,7 +13,7 @@ enum IniGroup{igMapView,igMain,igOther};
 enum IniKey{ikSkin,ikStationCustomFont,ikStationFont,ikStationBack,ikStationShadow,ikSBackColor,ikSShadowColor,
             ikSUpperCase,ikSWordWrap,ikSTransparency,
             ikMShowScrollbar,ikWFullScreen,ikMShowTime,ikMShowBackground,ikMAntialiasing,ikMFastScrolling,
-            ikMBackColor,ikMSimpleTransfers,ikMCleanCache,ikMLastFile,ikMCaching,ikWUiScale,ikMSwipeRoutes};
+            ikMBackColor,ikMSimpleTransfers,ikMCleanCache,ikMLastFile,ikMCaching,ikWUiScale,ikWUiButtonScale,ikMSwipeRoutes};
 
 typedef QMap<IniKey,QString> IniKeyMap;
 typedef QMap<IniGroup,IniKeyMap> IniSettingMap;
@@ -57,6 +57,7 @@ public:
 
      QFont appFont;
      qreal appUiScale;
+     qreal appUiButtonScale;
      int appIconSize;
      bool appFullscreen;
      bool appFirstStart;
@@ -87,8 +88,9 @@ private:
     Qt::GestureType m_gestureId;
 
 public slots:
-    void setScaleForUi(qreal UiScale);
+    void setScaleForUi(qreal UiScale=0.0,qreal UiButtonScale=0.0);
     void setScaleForUi(int UiScale) { setScaleForUi((qreal)(UiScale/100.0)); }
+    void setScaleForUiButtons(int UiScale) { setScaleForUi(Config.appUiScale,(qreal)(UiScale/100.0)); }
     void toggleLang(QString locale="");
     void setNodeDefault(bool checked,TMapNode *Node=NULL);
     void loadNodeDefault();
