@@ -209,13 +209,10 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
     && (!Map->config.enableCaching || (Map->config.enableCaching && Map->state.mapCached)) )
  {
   // write times
-  if(Map->mapDistance[ID]<INFINIT)
-  {
-   p->setFont(Map->params.nodeTimeFont);
-   p->setPen(Qt::white);
-   p->setBackgroundMode(Qt::TransparentMode);
-   p->drawText(RectEllipse,Qt::AlignCenter,Distance);                                          //QString::number(ID));
-  }
+  p->setFont(Map->params.nodeTimeFont);
+  p->setPen(Qt::white);
+  p->setBackgroundMode(Qt::TransparentMode);
+  p->drawText(RectEllipse,Qt::AlignCenter,Distance);                                          //QString::number(ID));
  }
  //else { p->setFont(QFont("Tahoma",5)); p->drawText(EllipseRect,Qt::AlignCenter,QString::number(int(ID)));}
 
