@@ -1,7 +1,7 @@
 #ifndef MAPROUTE_H
 #define MAPROUTE_H
 
-#include <QtGui/QGraphicsView>
+#include <QGraphicsView>
 #include <QList>
 #include "mapnode.h"
 
@@ -31,8 +31,10 @@ public:
 
     QPainterPath pathRoute;
 
-    //bool active;
-
+    //for nodes
+    QPen BeginPen,EndPen,ConstructPen,TransferPen,NormalPen,
+                         ConstructInfoPen,TransferInfoPen,NormalInfoPen;
+    QColor ColorDark;
 };
 
 #endif // MAPROUTE_H
