@@ -1627,6 +1627,7 @@ void TMapView::popupByTimer()
 {
  if(!nodeClick || !nodePopup) return;
  setDragMode(QGraphicsView::NoDrag);
+
  if(config.MobileVersion)
   nodePopup->popup(QPoint(rect().width()/2-nodePopup->width()/2,rect().height()-nodePopup->height())+mapToGlobal(rect().topLeft()));
  else
@@ -1689,6 +1690,8 @@ void TMapView::mouseReleaseEvent(QMouseEvent *event)
 
  //testTimer.start();
 
+  if(config.MobileVersion && nodeBegin && nodeEnd) popupByTimer();
+  else
   findTrack(nodeClick);
  //qDebug() << testTimer.elapsed();
  }
@@ -2030,7 +2033,9 @@ void TMapView::showTrack(int i)
 // selectedNode << track.selectedNode;
 // selectedEdge << track.selectedEdge;
 // mapDistance << track.mapDistance;
+
  info=getMessageTrackInfo(i);
+
  text=getMessageTrackDescription(i);
 // qDebug() << mapTrack.at(i).mapDistance;
  // caching calculations
@@ -2040,10 +2045,15 @@ void TMapView::showTrack(int i)
   else node->Distance="";
 
  emit nodeHasInfo(0);
- emit trackInfo(info);
  emit trackDescription(text);
- text=info+text;
+ if(config.MobileVersion)
+      text=(mapTrack.count()>1 ? QString::number(i+1)+") ":"")+info;
+ else text=info+text;
  emit trackText(text);
+
+ if(config.MobileVersion && mapTrack.count()>1)
+   info="<sup><font face=monospace>&nbsp;"+QString::number(i+1)+"&nbsp;</font></sup>"+info;
+ emit trackInfo(info);
  emit trackFinded(1);
 
  mapStartDragging();
@@ -2501,11 +2511,11 @@ bool TMapView::viewportEvent(QEvent *event)
  case QEvent::Gesture:
   if(QGesture *pinch=((QGestureEvent*)event)->gesture(Qt::PinchGesture))
   {
+   nodeClick=NULL;
    QPinchGesture::ChangeFlags changeFlags = ((QPinchGesture*)pinch)->changeFlags();
    if(changeFlags & QPinchGesture::ScaleFactorChanged)
    {
     scaleMap(((QPinchGesture*)pinch)->scaleFactor());
-    nodeClick=NULL;
    }
    return true;
   }
@@ -2522,14 +2532,12 @@ bool TMapView::viewportEvent(QEvent *event)
   }
 
  break;
-
- default:
-  return QGraphicsView::viewportEvent(event);
+ default: ;
  }
+ return QGraphicsView::viewportEvent(event);
 }
 
 
-
 //bool TMapView::OnSwipeGesture(QSwipeGesture* pSwipe)
 //{
 //   bool result = false;
