@@ -9,10 +9,10 @@ extern MainWindow *mainWnd;
 extern QString STYLE_MAP,SKIN_DEFAULT;
 //extern TMapView *map;
 
-TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
+TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map),TextDesc(NULL)
 {Q_UNUSED(parent);
  Ui::MainWindow *ui=mainWnd->ui;
- int Spacing=mainWnd->Config.appIconSize/4;
+ int Spacing=qRound(mainWnd->Config.appIconSize/10);
  DefaultIconSize=QSize(mainWnd->Config.appIconSize,mainWnd->Config.appIconSize);
 
  lTop =new QHBoxLayout;
@@ -78,11 +78,9 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
 
 
   textInfo = new QLabel("");
-  QFont TempFont=qApp->font();
-//#if !defined(Q_WS_MAEMO_5)
-  TempFont.setPixelSize(TempFont.pixelSize()/1.25);
-  textInfo->setFont(TempFont);
-//#endif
+//  QFont TempFont=qApp->font();
+//  TempFont.setPixelSize(TempFont.pixelSize()/1.25);
+//  textInfo->setFont(TempFont);
 
   textInfo->setMinimumWidth(0);
   textInfo->setMinimumHeight(0);
@@ -146,9 +144,9 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
   pal.setBrush(QPalette::Base, mainWnd->palette().color(QPalette::Window));
   pal.setColor(QPalette::Text,mainWnd->palette().color(QPalette::Text));
   TextDesc->setPalette(pal);
-  TempFont=qApp->font();
-  TempFont.setPixelSize(TempFont.pixelSize()/1.2);
-  TextDesc->setFont(TempFont);
+//  TempFont=qApp->font();
+//  TempFont.setPixelSize(TempFont.pixelSize()/1.2);
+//  TextDesc->setFont(TempFont);
   TextDesc->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
   TextDesc->setReadOnly(1);
   TextDesc->setFrameShape(QFrame::NoFrame);
@@ -183,7 +181,7 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
 #endif
 
   // Description
-  connect(map,SIGNAL(trackInfo(QString)),LabelInfo,SLOT(setText(QString)));
+  connect(map,SIGNAL(trackText(QString)),LabelInfo,SLOT(setText(QString)));
   connect(map,SIGNAL(trackDescription(QString)),TextDesc,SLOT(setText(QString)));
   connect(bOK,SIGNAL(clicked()),mainWnd,SLOT(showPageMap()));
 
@@ -266,6 +264,18 @@ void TMobileUi::setToolbarIconSize(int Size)
  {
   b->setIconSize(IconSize);
  }
+
+ QFont TempFont=qApp->font();
+ TempFont.setPixelSize(TempFont.pixelSize()/1.25);
+
+ QList<QLabel *> labels =  MapView->findChildren<QLabel *>();
+ foreach(QLabel *l,labels)
+ {
+  l->setFont(TempFont);
+ }
+
+ // LabelInfo->setFont(TempFont);
+ if(TextDesc) TextDesc->setFont(TempFont);
 }
 
 void TMobileUi::hideSearch(bool state)
