@@ -1,6 +1,6 @@
-#include <QtGui/QApplication>
-#include <QtGui/QPushButton>
-#include <QtGui/QDesktopWidget>
+#include <QApplication>
+#include <QPushButton>
+#include <QDesktopWidget>
 #include <QtDeclarative/QDeclarativeContext>
 #include <QtDeclarative/QDeclarativeItem>
 
@@ -43,7 +43,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 // context->setContextProperty("screenWidth", screenRect.width());
 // context->setContextProperty("screenHeight", screenRect.height());
 
-
+//  MainQML="harmattan";
  #if defined(MEEGO_EDITION_HARMATTAN)
   MainQML="harmattan";
  #else
@@ -54,14 +54,15 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
  viewer->setMainQmlFile("qrc:/"+MainQML+".qml");
  //viewer->setResizeMode(QDeclarativeView::SizeRootObjectToView);
 
+// work bad...
 // For Harmattan and N900 set OpenGL rendering
-#if defined(MEEGO_EDITION_HARMATTAN) //|| defined(Q_WS_MAEMO_5)
- QGLFormat fmt = QGLFormat::defaultFormat();
- fmt.setDirectRendering(1);
- fmt.setDoubleBuffer(1);
- QGLWidget *glWidget = new QGLWidget(fmt);
- viewer->setViewport(glWidget);
-#endif
+//#if defined(MEEGO_EDITION_HARMATTAN) //|| defined(Q_WS_MAEMO_5)
+// QGLFormat fmt = QGLFormat::defaultFormat();
+// fmt.setDirectRendering(1);
+// fmt.setDoubleBuffer(1);
+// QGLWidget *glWidget = new QGLWidget(fmt);
+// viewer->setViewport(glWidget);
+//#endif
 
 
 #if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN) || defined(MEEGO_EDITION_HARMATTAN)
