@@ -163,6 +163,7 @@ Settings::Settings(QWidget *parent) :
 
   connect(ui->checkWFullScreen,SIGNAL(clicked()),this,SLOT(changeSettings()));
   connect(ui->spinUiScale,SIGNAL(valueChanged(int)),mainWnd,SLOT(setScaleForUi(int)));
+  connect(ui->spinUiButtonScale,SIGNAL(valueChanged(int)),mainWnd,SLOT(setScaleForUiButtons(int)));
 
   connect(ui->cbSkin,SIGNAL(activated(QString)),this,SLOT(changeSettings()));
  }else // mobile
@@ -267,6 +268,7 @@ void Settings::on_bDefaultConfig_clicked()
 {
  loadSettingsToUi(DefaultConfig);
  ui->spinUiScale->setValue(100);
+ ui->spinUiButtonScale->setValue(100);
  ui->checkWFullScreen->setChecked(mainWnd->MobileVersion);
  ui->checkMCaching->setChecked(mainWnd->MobileVersion);
  ui->checkMSwipeRoutes->setChecked(mainWnd->MobileVersion);
@@ -307,7 +309,8 @@ IniSettingMap Settings::changeSettings()
  IniKeyMap MainKeys;
  MainKeys.insert(ikSkin,ui->cbSkin->currentText());
  MainKeys.insert(ikWFullScreen,QString::number(ui->checkWFullScreen->isChecked()));
- MainKeys.insert(ikWUiScale,QString::number(ui->spinUiScale->value()/100.0));
+ MainKeys.insert(ikWUiScale,QString::number(ui->spinUiScale->value()/qreal(100.0)));
+ MainKeys.insert(ikWUiButtonScale,QString::number(ui->spinUiButtonScale->value()/qreal(100.0)));
  Setting.insert(igMain,MainKeys);
 
  // [Other]
@@ -391,7 +394,8 @@ void Settings::loadSettingsToUi(const IniSettingMap &set)
  else ui->checkWFullScreen->setChecked(mainWnd->Config.appFullscreen);
  //value=key.value(ikWUiScale);
  //if(!value.isEmpty())
- ui->spinUiScale->setValue(mainWnd->Config.appUiScale*100);
+ ui->spinUiScale->setValue(qRound(mainWnd->Config.appUiScale*100));
+ ui->spinUiButtonScale->setValue(qRound(mainWnd->Config.appUiButtonScale*100));
 
  // [Other]
  value=set.value(igOther).value(ikMCleanCache);
